"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Configuration = void 0;
const vscode_1 = require("vscode");
const defaultConfig_1 = require("../defaultConfig");
class Configuration {
    constructor() {
        this.configuration = vscode_1.workspace.getConfiguration('tailwindcss-highlight');
    }
    get languages() {
        var _a;
        return (_a = this.configuration.get('languages')) !== null && _a !== void 0 ? _a : [];
    }
    get configs() {
        var _a, _b, _c, _d;
        const customVariantsConfig = (_a = this.configuration.get('customVariantsConfig')) !== null && _a !== void 0 ? _a : {};
        const defaultVariantsColor = (_b = this.configuration.get('defaultVariantsColor')) !== null && _b !== void 0 ? _b : '';
        const customUtilitiesConfig = (_c = this.configuration.get('customUtilitiesConfig')) !== null && _c !== void 0 ? _c : {};
        const enabledUtilities = (_d = this.configuration.get('enabledUtilities')) !== null && _d !== void 0 ? _d : defaultConfig_1.defaultEnabledUtilities;
        const config = Object.assign(Object.assign({}, customUtilitiesConfig), Object.entries(defaultConfig_1.defaultUtilitiesConfig).reduce((acc, [key, value]) => {
            var _a, _b, _c, _d, _e;
            acc[key] = {
                regex: (_b = (_a = customUtilitiesConfig[key]) === null || _a === void 0 ? void 0 : _a.regex) !== null && _b !== void 0 ? _b : value.regex,
                color: (_d = (_c = customUtilitiesConfig[key]) === null || _c === void 0 ? void 0 : _c.color) !== null && _d !== void 0 ? _d : value.color,
                style: (_e = customUtilitiesConfig[key]) === null || _e === void 0 ? void 0 : _e.style
            };
            return acc;
        }, {}));
        const customVariants = Object.values(customVariantsConfig).flatMap((i) => i);
        return Object.assign(Object.assign(Object.assign({}, Object.entries(config).reduce((acc, [key, value]) => {
            var _a, _b, _c, _d;
            acc[key] = {
                enable: true,
                regex: (_a = value.regex) !== null && _a !== void 0 ? _a : '',
                options: enabledUtilities.includes(key)
                    ? (_b = value.style) !== null && _b !== void 0 ? _b : highlightStyle((_c = value.color) !== null && _c !== void 0 ? _c : '')
                    : borderStyle((_d = value.color) !== null && _d !== void 0 ? _d : '')
            };
            return acc;
        }, {})), Object.entries(customVariantsConfig).reduce((acc, [key, value]) => {
            acc[`variants:${value.join()}`] = {
                enable: true,
                options: {
                    color: key
                },
                regex: `(?<=[:\`\'\"\\s])(${value.join('|')}):`
            };
            return acc;
        }, {})), { 
            // default variants
            'variants:other': {
                enable: true,
                options: {
                    color: defaultVariantsColor
                },
                regex: `(?<=[:\`\'\"\\s])(?!(${customVariants.join('|')}))([^\`\'\"\\s]+):`
            } });
    }
}
exports.Configuration = Configuration;
const borderStyle = (color) => ({
    backgroundColor: '',
    borderStyle: 'dashed',
    borderWidth: '0 0 1px 0',
    borderColor: color
});
const highlightStyle = (color) => ({
    color: '#333',
    borderRadius: '0.25rem',
    backgroundColor: color
});
