"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Decoration = void 0;
const vscode_1 = require("vscode");
const utils_1 = require("./utils");
class Decoration {
    constructor(configuration) {
        this.timer = undefined;
        this.configuration = configuration;
        this.decorators = Object.entries(configuration.configs)
            .filter((config) => config[1].enable)
            .sort((a, b) => {
            console.log(a[0]);
            if (a[0].startsWith('variants:') &&
                !['variants:other', 'variants:responsive'].includes(a[0])) {
                return -1;
            }
            return 0;
        })
            .map((config) => {
            return {
                regex: config[1].regex,
                decorator: vscode_1.window.createTextEditorDecorationType(config[1].options)
            };
        });
    }
    decorate(editor) {
        if (editor == null)
            return;
        const document = editor.document;
        const text = document.getText();
        const classNames = (0, utils_1.getClassNames)(text);
        this.decorators.forEach((decorator) => {
            const regex = new RegExp(decorator.regex, 'g');
            const chars = [];
            classNames.forEach((className) => {
                const utilities = (0, utils_1.getUtility)(className.value, regex);
                utilities.forEach((utility) => {
                    const start = document.positionAt(className.start + utility.start);
                    const end = document.positionAt(className.start + utility.end);
                    const range = new vscode_1.Range(start, end);
                    chars.push({ range });
                });
                editor.setDecorations(decorator.decorator, chars);
            });
        });
    }
    update(configuration) {
        if (configuration != null) {
            this.configuration = configuration;
            this.decorators = Object.entries(configuration.configs)
                .filter((config) => config[1].enable)
                .map((config) => {
                return {
                    regex: config[1].regex,
                    decorator: vscode_1.window.createTextEditorDecorationType(config[1].options)
                };
            });
        }
        const editor = vscode_1.window.activeTextEditor;
        if (editor == null)
            return;
        const languageId = editor.document.languageId;
        if (!this.configuration.languages.includes(languageId))
            return;
        if (this.timer != null) {
            clearTimeout(this.timer);
            this.timer = undefined;
        }
        this.timer = setTimeout(() => {
            this.decorate(editor);
        }, 500);
    }
    dispose() {
        this.decorators.forEach((decorator) => {
            decorator.decorator.dispose();
        });
    }
}
exports.Decoration = Decoration;
